# bifrost_bridge


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This file will become your README and also the index of your
documentation.

## Developer Guide

If you are new to using `nbdev` here are some useful pointers to get you
started.

### Install bifrost_bridge in Development mode

``` sh
# make sure bifrost_bridge package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to bifrost_bridge
$ nbdev_prepare
```

## Usage

### Installation

Install latest from the GitHub
[repository](https://github.com/$GIT_USER_NAME/bifrost_bridge):

``` sh
$ pip install git+https://github.com/$GIT_USER_NAME/bifrost_bridge.git
```

or from [conda](https://anaconda.org/$GIT_USER_NAME/bifrost_bridge)

``` sh
$ conda install -c $GIT_USER_NAME bifrost_bridge
```

or from [pypi](https://pypi.org/project/bifrost_bridge/)

``` sh
$ pip install bifrost_bridge
```

### Documentation

Documentation can be found hosted on this GitHub
[repository](https://github.com/$GIT_USER_NAME/bifrost_bridge)’s
[pages](https://$GIT_USER_NAME.github.io/bifrost_bridge/). Additionally
you can find package manager specific guidelines on
[conda](https://anaconda.org/$GIT_USER_NAME/bifrost_bridge) and
[pypi](https://pypi.org/project/bifrost_bridge/) respectively.

## How to use

Fill me in please! Don’t forget code examples:

``` python
1+1
```

    2
